@@ -4,9 +4,11 @@
 """
 import concurrent
 import logging
+import re
 from typing import Any, Dict, List
 
 import requests
+from component_registry_bindings.bindings.python_client.models import Component
 
 from griffon import CORGI_API_URL, OSIDB_API_URL, CorgiService, OSIDBService
 
@@ -132,6 +134,7 @@ class products_containing_specific_component_query:
         "search_related_url",
         "search_community",
         "search_upstreams",
+        "filter_rh_naming",
     ]
 
     def __init__(self, params: dict) -> None:
@@ -158,12 +161,12 @@ class products_containing_component_query:
         "namespace",
         "component_type",
         "strict_name_search",
-        "affect_mode",
         "search_latest",
         "search_all",
         "search_related_url",
         "search_community",
         "search_upstreams",
+        "filter_rh_naming",
     ]
 
     def __init__(self, params: dict) -> None:
@@ -179,31 +182,33 @@ class products_containing_component_query:
         self.search_related_url = self.params.get("search_related_url")
         self.search_community = self.params.get("search_community")
         self.search_upstreams = self.params.get("search_upstreams")
+        self.filter_rh_naming = self.params.get("filter_rh_naming")
 
     def execute(self) -> List[Dict[str, Any]]:
-        cond = {"view": "latest"}
-        if not self.strict_name_search:
-            cond["re_name"] = self.component_name  # type: ignore
-        else:
-            cond["name"] = self.component_name  # type: ignore
-
-        if self.component_type:
-            cond["type"] = self.component_type
 
         url: str = f"{CORGI_API_URL}/api/v1/components"
 
         results = []
         if self.search_latest:
+            cond = {"view": "latest"}
+            if not self.strict_name_search:
+                cond["re_name"] = self.component_name  # type: ignore
+            else:
+                cond["name"] = self.component_name  # type: ignore
+            if self.component_type:
+                cond["type"] = self.component_type
+            cond["namespace"] = "REDHAT"
             result = self.corgi_session.components.retrieve_list(**cond, limit=1000)
             results = result.results
 
         if self.search_related_url:
             # TODO - not in bindings yet
-            params = params = {
+            params = {
                 "include_fields": "name,arch,namespace,release,version,nvr,type,link,purl,software_build,product_versions,product_streams,sources,upstreams",  # noqa
                 "related_url": self.component_name,
                 "limit": 10000,
             }
+            params["namespace"] = "REDHAT"
             if self.component_type:
                 params["type"] = self.component_type
             related_url_search = requests.get(
@@ -352,6 +357,45 @@ class products_containing_component_query:
                         if c["upstreams"]:
                             component["upstream_purl"] = c["upstreams"][0]["purl"]
                         results.append(component)
+
+        if self.filter_rh_naming:
+            flags = re.IGNORECASE
+            patterns = [
+                # binutils
+                re.compile(
+                    f"(devtoolset\\-[0-9]+\\-|mingw\\-|gcc\\-toolset\\-[0-9]+\\-)?{self.component_name}[0-9\\.]*$",  # noqa
+                    flags=flags,
+                ),
+                # compat-* style
+                re.compile(f"(compat\\-)?{self.component_name}[0-9\\.]*(\\-[0-9]+)?$", flags=flags),
+                # kernel
+                re.compile(f"^{self.component_name}(\\-rt)?$", flags=flags),
+                # qemu
+                re.compile(f"^{self.component_name}(\\-kvm(\\-rhev|\\-ma)?)?$", flags=flags),
+                # webkit
+                re.compile(f"^{self.component_name}([0-9])?(gtk)?([0-9])?$", flags=flags),
+            ]
+
+            filtered_results = []
+            for result in results:
+                is_matched = False
+                for p in patterns:
+                    if is_matched:
+                        break
+                    if type(result) == Component:
+                        m = p.match(result.name)
+                        if m:
+                            is_matched = True
+                    else:
+                        m = p.match(result["name"])
+                        if m:
+                            is_matched = True
+
+                if is_matched:
+                    filtered_results.append(result)
+
+            results = filtered_results
+
         return results
 
 
